/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { EventEmitter, TemplateRef, ElementRef } from '@angular/core';
import { DialogAction } from './models/dialog-action';
import { ActionsLayout } from '../common/actions-layout';
import { DialogActionDivider } from './models/dialog-action-divider';
import * as i0 from "@angular/core";
/**
 * Represents the action buttons of the Dialog.
 * ([See example.]({% slug actionbuttons_dialog %}))
 *
 * ```html
 * <kendo-dialog>
 *  <kendo-dialog-actions>
 *     <button kendoButton fillMode="flat" themeColor="primary" (click)="onPrimaryActionClick()">
 *       Primary Action
 *    </button>
 *  </kendo-dialog-actions>
 * </kendo-dialog>
 * ```
 */
export declare class DialogActionsComponent {
    el: ElementRef;
    /**
     * Allows the declarative specification of the Dialog `actions`.
     */
    set actions(value: DialogAction[] | TemplateRef<any>);
    /**
     * @hidden
     */
    actionsArray: DialogAction[];
    /**
     * @hidden
     */
    actionsTemplate: TemplateRef<any>;
    /**
     * Sets the possible layout of the action buttons.
     * @default 'stretched'
     */
    layout: ActionsLayout;
    /**
     * Fires when the user clicks an action button.
     */
    action: EventEmitter<DialogAction>;
    hostClasses: boolean;
    get startClassName(): boolean;
    get centerClassName(): boolean;
    get endClassName(): boolean;
    get stretchedClassName(): boolean;
    constructor(el: ElementRef);
    /**
     * @hidden
     */
    onButtonClick(action: DialogAction, _e?: any): void;
    /**
     * @hidden
     */
    isDivider(action: DialogAction | DialogActionDivider): boolean;
    static ɵfac: i0.ɵɵFactoryDeclaration<DialogActionsComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<DialogActionsComponent, "kendo-dialog-actions", never, { "actions": { "alias": "actions"; "required": false; }; "layout": { "alias": "layout"; "required": false; }; }, { "action": "action"; }, never, ["*"], true, never>;
}
