/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { ButtonFillMode, ButtonThemeColor } from "@progress/kendo-angular-buttons";
import { SVGIcon } from "@progress/kendo-svg-icons";
/**
 * Represents the settings for Dialog actions when you open a Dialog through `DialogService`.
 *
 * Use the `DialogAction` class to configure action buttons in the Dialog. ([See example.]({% slug api_dialog_dialogservice %}#toc-open))
 *
 */
export declare class DialogAction {
    /**
     * Sets the text of the action button.
     */
    text: string;
    /**
     * Sets the theme color of the action button. The theme color applies to the background, border, and text.
     */
    themeColor?: ButtonThemeColor;
    /**
     * Sets the background and border styles of the action button.
     */
    fillMode?: ButtonFillMode;
    /**
     * Sets the CSS classes for the action button. Accepts any value supported by [`ngClass`](link:site.data.urls.angular['ngclassapi']).
     */
    cssClass?: any;
    /**
     * Sets the [SVG icon](slug:svgicon_list) to display in the action button.
     */
    svgIcon?: SVGIcon;
    /**
     * Sets the name of the [font icon](slug:icon_list) to display in the action button.
     */
    icon?: string;
    /**
     * @hidden
     */
    disabled?: boolean;
}
