/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { DialogAnimationType } from "../../common/animation-types";
import { AnimationDirection } from '../../common/dialog-animation-direction';
/**
 * Represents the settings for Dialog animations when you open the Dialog component.
 *
 * Use the `DialogAnimation` interface to configure animation duration, type, and direction. ([See example.]({% slug animations_dialog %}))
 *
 */
export interface DialogAnimation {
    /**
     * Sets the duration of the Dialog opening animation in milliseconds.
     */
    duration?: number;
    /**
     * Sets the Dialog opening animation type.
     */
    type?: DialogAnimationType;
    /**
     * Sets the direction of the Dialog opening animation. Applies to the `slide` and `expand` animation types.
     */
    direction?: AnimationDirection;
}
