/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { DialogActionsComponent } from "./dialog/dialog-actions.component";
import { DialogContainerDirective } from "./dialog/dialog-container.directive";
import { DialogTitleBarComponent } from "./dialog/dialog-titlebar.component";
import { DialogComponent } from "./dialog/dialog.component";
import { CustomMessagesComponent } from "./localization/custom-messages.component";
import { WindowCloseActionDirective } from "./window/actions/window-close-action.directive";
import { WindowMaximizeActionDirective } from "./window/actions/window-maximize-action.directive";
import { WindowMinimizeActionDirective } from "./window/actions/window-minimize-action.directive";
import { WindowRestoreActionDirective } from "./window/actions/window-restore-action.directive";
import { WindowContainerDirective } from "./window/window-container.directive";
import { WindowTitleBarComponent } from "./window/window-titlebar.component";
import { WindowComponent } from "./window/window.component";
/**
 * Represents the utility array that that contains all `Dialog`-related components and directives.
 *
 * Use `KENDO_DIALOG` to import all Dialog components and directives at once.
 *
 * @example
 * ```typescript
 * import { Component } from '@angular/core';
 * import { KENDO_DIALOG } from '@progress/kendo-angular-dialog';
 *
 * @Component({
 *   selector: 'my-dialog-app',
 *   standalone: true,
 *   imports: [KENDO_DIALOG],
 *   template: `...`
 * })
 * export class DialogAppComponent {}
 * ```
 */
export declare const KENDO_DIALOG: readonly [typeof DialogComponent, typeof DialogTitleBarComponent, typeof DialogContainerDirective, typeof DialogActionsComponent, typeof CustomMessagesComponent];
/**
 * Represents the utility array that contains all `Window`-related components and directives.
 *
 * Use `KENDO_WINDOW` to import all Window components and directives at once.
 *
 * @example
 * ```typescript
 * import { Component } from '@angular/core';
 * import { KENDO_WINDOW } from '@progress/kendo-angular-dialog';
 *
 * @Component({
 *   selector: 'my-window-app',
 *   standalone: true,
 *   imports: [KENDO_WINDOW],
 *   template: `...`
 * })
 * export class WindowAppComponent {}
 * ```
 */
export declare const KENDO_WINDOW: readonly [typeof WindowComponent, typeof WindowCloseActionDirective, typeof WindowMinimizeActionDirective, typeof WindowMaximizeActionDirective, typeof WindowRestoreActionDirective, typeof WindowTitleBarComponent, typeof WindowContainerDirective, typeof DialogActionsComponent, typeof CustomMessagesComponent];
/**
 * Represents the utility array that contains all `@progress/kendo-angular-dialog`-related components and directives.
 *
 * Use `KENDO_DIALOGS` to import all Dialog and Window components and directives at once.
 *
 * @example
 * ```typescript
 * import { Component } from '@angular/core';
 * import { KENDO_DIALOGS } from '@progress/kendo-angular-dialog';
 *
 * @Component({
 *   selector: 'my-app',
 *   standalone: true,
 *   imports: [KENDO_DIALOGS],
 *   template: `...`
 * })
 * export class AppComponent {}
 * ```
 */
export declare const KENDO_DIALOGS: readonly [typeof DialogComponent, typeof DialogTitleBarComponent, typeof DialogContainerDirective, typeof DialogActionsComponent, typeof CustomMessagesComponent, typeof WindowComponent, typeof WindowCloseActionDirective, typeof WindowMinimizeActionDirective, typeof WindowMaximizeActionDirective, typeof WindowRestoreActionDirective, typeof WindowTitleBarComponent, typeof WindowContainerDirective, typeof DialogActionsComponent, typeof CustomMessagesComponent];
