/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { LocalizationService } from '@progress/kendo-angular-l10n';
import { Messages } from './messages';
import * as i0 from "@angular/core";
/**
 * Represents a component for customizing the messages in Dialog and Window components.
 *
 * Use the `CustomMessagesComponent` to override default messages with custom text. ([See example.](slug:globalization_dialogs#toc-internationalization)).
 *
 * @example
 * ```typescript
 * import { CustomMessagesComponent } from './custom-messages.component';
 *
 * @Component({
 *   selector: 'my-dialog',
 *   template: `
 *     <kendo-dialog>
 *       <kendo-dialog-messages
 *         [closeTitle]="'Close dialog'"
 *         [restoreTitle]="'Restore dialog'"
 *         [maximizeTitle]="'Maximize dialog'"
 *         [minimizeTitle]="'Minimize dialog'">
 *       </kendo-dialog-messages>
 *     </kendo-dialog>
 *   `
 * })
 * export class MyDialogComponent {}
 * ```
 */
export declare class CustomMessagesComponent extends Messages {
    protected service: LocalizationService;
    constructor(service: LocalizationService);
    protected get override(): boolean;
    static ɵfac: i0.ɵɵFactoryDeclaration<CustomMessagesComponent, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<CustomMessagesComponent, "kendo-dialog-messages, kendo-window-messages", never, {}, {}, never, never, true, never>;
}
