/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { ComponentRef } from "@angular/core";
import { Observable } from "rxjs";
import { WindowComponent } from "../window.component";
import { WindowCloseResult } from "./window-close-result";
/**
 * Holds references to the Window instance. Controls Windows opened through `WindowService`. ([See example.]({% slug api_dialog_windowservice %}#toc-open))
 */
export declare class WindowRef {
    /**
     * Represents a reference to the Window instance.
     */
    window: ComponentRef<WindowComponent>;
    /**
     * Represents a reference to the child component of the Window. Available when you open the Window with [component content](slug:service_window#toc-rendering-the-content-area).
     */
    content: ComponentRef<any>;
    /**
     * Allows you to close the Window by using code. When called with no arguments, the `result` Observable is of type `WindowCloseResult`. When called with an argument, the `result` Observable holds the provided value.
     */
    close: Function;
    /**
     * Emits events when the Window is closed through the `Esc` key, the **Close** button of the title bar, or by calling the `close` method. When the Window is closed with the title bar button, `Esc`, or by calling `close` with no arguments, the result is of type [`WindowCloseResult`]({% slug api_dialog_windowcloseresult %}). When `close` is called with an argument, the result is the passed argument.
     */
    result: Observable<WindowCloseResult>;
}
